"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FullScreenCssGenerator = exports.FullScreenGeneratorOptions = void 0;
const CssGenerator_base_1 = require("./CssGenerator.base");
/**
 * 全屏配置
 *
 * @export
 * @class FullScreenGeneratorOptions
 */
class FullScreenGeneratorOptions {
    constructor() {
        this.image = '';
        this.opacity = 0.91; // 建议在 0.85 ~ 0.95 之间微调
        this.size = 'cover';
        this.position = 'center';
        this.interval = 0;
    }
}
exports.FullScreenGeneratorOptions = FullScreenGeneratorOptions;
/**
 * 全屏样式生成
 *
 * @export
 * @class FullScreenCssGenerator
 * @extends {AbsCssGenerator<FullScreenGeneratorOptions>}
 */
class FullScreenCssGenerator extends CssGenerator_base_1.AbsCssGenerator {
    getCarouselCss(images, interval) {
        const animationName = 'background-fullscreen-carousel';
        const keyframeCSS = this.createKeyFrames(images, interval, animationName);
        if (!keyframeCSS) {
            return '';
        }
        return (0, CssGenerator_base_1.css) `
            body {
                animation: ${animationName} ${images.length * interval}s infinite;
            }
            ${keyframeCSS}
        `;
    }
    getCss(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const { size, position, opacity, image, interval } = Object.assign(Object.assign({}, new FullScreenGeneratorOptions()), options);
            // ------ 处理图片 ------
            const images = this.normalizeImageUrls(Array.isArray(image) ? image : [image]);
            return (0, CssGenerator_base_1.css) `
            body {
                background-size: ${size};
                background-repeat: no-repeat;
                background-attachment: fixed; // 兼容 code-server，其他的不影响
                background-position: ${position};
                opacity: ${opacity};
                background-image: url('${images[0]}');
            }
            ${this.getCarouselCss(images, interval)}
        `;
        });
    }
}
exports.FullScreenCssGenerator = FullScreenCssGenerator;
//# sourceMappingURL=CssGenerator.fullscreen.js.map